==> igniteui-webcomponents-core-4.0.2.tgz: package/esm5/lib/GeographicShapeSeriesBaseBaseDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import * as tslib_1 from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { GeographicMapSeriesHostDescriptionMetadata } from "./GeographicMapSeriesHostDescriptionMetadata";
/**
 * @hidden
 */
var GeographicShapeSeriesBaseBaseDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    tslib_1.__extends(GeographicShapeSeriesBaseBaseDescriptionMetadata, _super);
    function GeographicShapeSeriesBaseBaseDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    GeographicShapeSeriesBaseBaseDescriptionMetadata.b = function (a) {
        if (GeographicShapeSeriesBaseBaseDescriptionMetadata.a == null) {
            GeographicShapeSeriesBaseBaseDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            GeographicShapeSeriesBaseBaseDescriptionMetadata.c(GeographicShapeSeriesBaseBaseDescriptionMetadata.a);
        }
        if (a.j(GeographicShapeSeriesBaseBaseDescriptionMetadata.a)) {
            return;
        }
        a.y(GeographicShapeSeriesBaseBaseDescriptionMetadata.a);
    };
    GeographicShapeSeriesBaseBaseDescriptionMetadata.c = function (a) {
        GeographicMapSeriesHostDescriptionMetadata.c(a);
    };
    GeographicShapeSeriesBaseBaseDescriptionMetadata.d = function (a) {
        GeographicShapeSeriesBaseBaseDescriptionMetadata.b(a);
        a.z("GeographicShapeSeriesBaseBase", GeographicShapeSeriesBaseBaseDescriptionMetadata.a);
    };
    GeographicShapeSeriesBaseBaseDescriptionMetadata.$t = markType(GeographicShapeSeriesBaseBaseDescriptionMetadata, 'GeographicShapeSeriesBaseBaseDescriptionMetadata');
    GeographicShapeSeriesBaseBaseDescriptionMetadata.a = null;
    return GeographicShapeSeriesBaseBaseDescriptionMetadata;
}(Base));
export { GeographicShapeSeriesBaseBaseDescriptionMetadata };

==> igniteui-webcomponents-core-4.2.5.tgz: package/esm5/lib/GeographicShapeSeriesBaseBaseDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import * as tslib_1 from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { GeographicMapSeriesHostDescriptionMetadata } from "./GeographicMapSeriesHostDescriptionMetadata";
/**
 * @hidden
 */
var GeographicShapeSeriesBaseBaseDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    tslib_1.__extends(GeographicShapeSeriesBaseBaseDescriptionMetadata, _super);
    function GeographicShapeSeriesBaseBaseDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    GeographicShapeSeriesBaseBaseDescriptionMetadata.b = function (a) {
        if (GeographicShapeSeriesBaseBaseDescriptionMetadata.a == null) {
            GeographicShapeSeriesBaseBaseDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            GeographicShapeSeriesBaseBaseDescriptionMetadata.c(GeographicShapeSeriesBaseBaseDescriptionMetadata.a);
        }
        if (a.k(GeographicShapeSeriesBaseBaseDescriptionMetadata.a)) {
            return;
        }
        a.aa(GeographicShapeSeriesBaseBaseDescriptionMetadata.a);
    };
    GeographicShapeSeriesBaseBaseDescriptionMetadata.c = function (a) {
        GeographicMapSeriesHostDescriptionMetadata.c(a);
    };
    GeographicShapeSeriesBaseBaseDescriptionMetadata.d = function (a) {
        GeographicShapeSeriesBaseBaseDescriptionMetadata.b(a);
        a.ab("GeographicShapeSeriesBaseBase", GeographicShapeSeriesBaseBaseDescriptionMetadata.a);
    };
    GeographicShapeSeriesBaseBaseDescriptionMetadata.$t = markType(GeographicShapeSeriesBaseBaseDescriptionMetadata, 'GeographicShapeSeriesBaseBaseDescriptionMetadata');
    GeographicShapeSeriesBaseBaseDescriptionMetadata.a = null;
    return GeographicShapeSeriesBaseBaseDescriptionMetadata;
}(Base));
export { GeographicShapeSeriesBaseBaseDescriptionMetadata };
